# -*- coding: utf-8 -*-
from setuphelpers import *
import glob

app_name = "mockoon"
uninstall_dir = makepath(os.environ['LOCALAPPDATA'], 'Programs', app_name)  # Target the correct directory
uninstall_exe_name = "Uninstall Mockoon.exe"  # Name of the uninstall executable

def install():
    bin_name = glob.glob('*.exe')[0]  # Find the .exe file in the current directory
    app_path = makepath(uninstall_dir, bin_name)  # Define the target path for the .exe
    
    # Installing the software
    killalltasks(ensure_list(control.impacted_process))
    
    if isdir(uninstall_dir) and force:  # If the directory exists and 'force' is enabled, remove it
        remove_tree(uninstall_dir)
    
    mkdirs(uninstall_dir)  # Create the target directory if necessary
    filecopyto(bin_name, app_path)  # Copy the .exe file to the target directory
    
    

    # Identify the path of the installed Mockoon executable
    installed_executable = find_installed_executable(app_name)

    # Create shortcuts to the installed executable, not the installer
    if installed_executable:
        create_desktop_shortcut(app_name, target=installed_executable)
        create_programs_menu_shortcut(app_name, target=installed_executable)

def find_installed_executable(app_name):
    """
    Find the installed Mockoon executable in the installation folder.
    """
    installed_paths = installed_softwares(app_name)
    if installed_paths:
        # Search for the executable in the installed paths
        for software in installed_paths:
            path = software.get('install_location', '')
            exe_files = glob.glob(makepath(path, '*.exe'))  # Search for .exe files in the installation directory
            if exe_files:
                return exe_files[0]  # Return the first .exe found
    return None

def uninstall():
    # Uninstalling the software
    killalltasks(ensure_list(control.impacted_process))

    # Complete path to the uninstall executable
    uninstall_path = makepath(uninstall_dir, uninstall_exe_name)
    
    if isfile(uninstall_path):  # Check if the uninstall file exists
        # Run the uninstall program in silent mode
        print(f"Uninstalling Mockoon via: {uninstall_path}")
        run(f'"{uninstall_path}" ')  # Use /S for silent uninstallation if supported
        wait_uninstallkey_absent(app_name, max_loop=600)
    else:
        print(f"Uninstall file not found: {uninstall_path}")
    
    # Remove remaining files
    if isdir(uninstall_dir):
        remove_tree(uninstall_dir)

    # Remove shortcuts
    remove_desktop_shortcut(app_name)
    remove_programs_menu_shortcut(app_name)
